### Instructional Jupyter notebooks
The jupyter notebooks in this folder exemplify the use of rbatools.

#### --------------------> Please note that before running the notebooks, rba models need to be obtained from https://github.com/SysBioInra/Bacterial-RBA-models and be stored in the same directory as the RBAtools directory
